@@ -44,12 +44,8 @@
 
 // ---------- local macro definitions
 #define SQ(x) ( (x) * (x) )
-#define INIT_MEM(x) memset(&(x), 0, sizeof((x)))
 // ---------- local type definitions
 
-// ---------- empty initializers
-const CWMFDataParams empty_CWMFDataParams;
-
 // ---------- Global variables
 
 // ---------- local prototypes
@@ -80,9 +76,10 @@ XLALCWMakeFakeMultiData ( MultiSFTVector **multiSFTs,			///< [out] pointer to op
   const MultiLIGOTimeGPSVector *multiTimestamps = &(dataParams->multiTimestamps);
 
   // check multi-detector input
-  XLAL_CHECK ( dataParams->detInfo.length >= 1, XLAL_EINVAL );
-  UINT4 numDet = dataParams->detInfo.length;
+  XLAL_CHECK ( dataParams->multiIFO.length >= 1, XLAL_EINVAL );
+  UINT4 numDet = dataParams->multiIFO.length;
   XLAL_CHECK ( multiTimestamps->length == numDet, XLAL_EINVAL, "Inconsistent number of IFOs: detInfo says '%d', multiTimestamps says '%d'\n", numDet, multiTimestamps->length );
+  XLAL_CHECK ( dataParams->multiNoiseFloor.length == numDet, XLAL_EINVAL );
 
   // check Tsft, consistent over detectors
   REAL8 Tsft = multiTimestamps->data[0]->deltaT;
@@ -111,10 +108,11 @@ XLALCWMakeFakeMultiData ( MultiSFTVector **multiSFTs,			///< [out] pointer to op
     {
       /* detector params */
       CWMFDataParams dataParamsX = (*dataParams); // struct-copy for general settings
-      dataParamsX.detInfo.length = 1;
-      dataParamsX.detInfo.sites[0] = dataParams->detInfo.sites[X];
-      dataParamsX.detInfo.sqrtSn[0] = dataParams->detInfo.sqrtSn[X];
-      MultiLIGOTimeGPSVector mTimestamps = empty_MultiLIGOTimeGPSVector;
+      dataParamsX.multiIFO.length = 1;
+      dataParamsX.multiIFO.sites[0] = dataParams->multiIFO.sites[X];
+      dataParamsX.multiNoiseFloor.length = 1;
+      dataParamsX.multiNoiseFloor.sqrtSn[0] = dataParams->multiNoiseFloor.sqrtSn[X];
+      MultiLIGOTimeGPSVector XLAL_INIT_DECL(mTimestamps);
       mTimestamps.length = 1;
       mTimestamps.data = &(multiTimestamps->data[X]); // such that pointer mTimestamps.data[0] = multiTimestamps->data[X]
       dataParamsX.multiTimestamps = mTimestamps;
@@ -164,7 +162,8 @@ XLALCWMakeFakeData ( SFTVector **SFTvect,
 
   XLAL_CHECK ( dataParams != NULL, XLAL_EINVAL );
   XLAL_CHECK ( edat != NULL, XLAL_EINVAL );
-  XLAL_CHECK ( dataParams->detInfo.length ==1, XLAL_EINVAL );
+  XLAL_CHECK ( dataParams->multiIFO.length == 1, XLAL_EINVAL );
+  XLAL_CHECK ( dataParams->multiNoiseFloor.length == 1, XLAL_EINVAL );
   XLAL_CHECK ( dataParams->multiTimestamps.length == 1, XLAL_EINVAL );
   XLAL_CHECK ( dataParams->multiTimestamps.data[0] != NULL, XLAL_EINVAL );
 
@@ -174,7 +173,7 @@ XLALCWMakeFakeData ( SFTVector **SFTvect,
   REAL8 fSamp = 2.0 * fBand;
 
   const LIGOTimeGPSVector *timestamps = dataParams->multiTimestamps.data[0];
-  const LALDetector *site = &dataParams->detInfo.sites[0];
+  const LALDetector *site = &dataParams->multiIFO.sites[0];
   REAL8 Tsft = timestamps->deltaT;
 
   // if SFT output requested: need *effective* fMin and Band consistent with SFT bins
@@ -247,7 +246,7 @@ XLALCWMakeFakeData ( SFTVector **SFTvect,
       XLAL_CHECK ( XLALGetTransientWindowTimespan ( &t0, &t1, pulsarParams->Transient ) == XLAL_SUCCESS, XLAL_EFUNC );
 
       // use latest possible start-time: max(t0,firstGPS), but not later than than lastGPS
-      LIGOTimeGPS signalStartGPS; INIT_MEM ( signalStartGPS );
+      LIGOTimeGPS XLAL_INIT_DECL(signalStartGPS);
       if ( t0 <= firstGPS_REAL8 ) {
         signalStartGPS = firstGPS;
       } else if ( t0 >= lastGPS_REAL8 ) {
@@ -258,7 +257,7 @@ XLALCWMakeFakeData ( SFTVector **SFTvect,
       }
 
       // use earliest possible end-time: min(t1,lastGPS), but not earlier than firstGPS
-      LIGOTimeGPS signalEndGPS; INIT_MEM ( signalEndGPS );
+      LIGOTimeGPS XLAL_INIT_DECL(signalEndGPS);
       if ( t1 >= lastGPS_REAL8 ) {
         signalEndGPS = lastGPS;
       } else if ( t1 <= firstGPS_REAL8 ) {
@@ -276,10 +275,10 @@ XLALCWMakeFakeData ( SFTVector **SFTvect,
           XLAL_CHECK ( (Tseries_sum = XLALAddREAL4TimeSeries ( Tseries_sum, Tseries_i )) != NULL, XLAL_EFUNC );
           XLALDestroyREAL4TimeSeries ( Tseries_i );
         }
-    } // for iInj = 1 ... (numPulsars-1)
+    } // for iInj < numSources
 
-  // add Gaussian noise if requested
-  REAL8 sqrtSn = dataParams->detInfo.sqrtSn[0];
+  /* add Gaussian noise if requested */
+  REAL8 sqrtSn = dataParams->multiNoiseFloor.sqrtSn[0];
   if ( sqrtSn > 0)
     {
       REAL8 noiseSigma = sqrtSn * sqrt ( fBand );
@@ -301,7 +300,7 @@ XLALCWMakeFakeData ( SFTVector **SFTvect,
           XLAL_CHECK ( (window = XLALCreateNamedREAL4Window ( dataParams->SFTWindowType, dataParams->SFTWindowBeta, numTimesteps )) != NULL, XLAL_EFUNC );
         } // if uvar->SFTwindowName
 
-      SFTParams sftParams = empty_SFTParams;
+      SFTParams XLAL_INIT_DECL(sftParams);
       sftParams.Tsft = Tsft;
       sftParams.timestamps = timestamps;
       sftParams.noiseSFTs = NULL;	// not used here any more!
@@ -389,7 +388,7 @@ XLALGenerateCWSignalTS ( const PulsarParams *pulsarParams,	///< input CW pulsar-
   /*----------------------------------------
    * fill old-style PulsarSignalParams struct
    *----------------------------------------*/
-  PulsarSignalParams params = empty_PulsarSignalParams;
+  PulsarSignalParams XLAL_INIT_DECL(params);
   params.pulsar.refTime            = pulsarParams->Doppler.refTime;
   params.pulsar.position.system    = COORDINATESYSTEM_EQUATORIAL;
   params.pulsar.position.longitude = pulsarParams->Doppler.Alpha;
@@ -400,7 +399,11 @@ XLALGenerateCWSignalTS ( const PulsarParams *pulsarParams,	///< input CW pulsar-
   params.pulsar.psi                = pulsarParams->Amp.psi;
   params.pulsar.f0                 = pulsarParams->Doppler.fkdot[0];
   params.pulsar.spindown           = spindown;
-  params.orbit                     = pulsarParams->Doppler.orbit;
+  params.orbit.tp                  = pulsarParams->Doppler.tp;
+  params.orbit.argp                = pulsarParams->Doppler.argp;
+  params.orbit.asini               = pulsarParams->Doppler.asini;
+  params.orbit.ecc                 = pulsarParams->Doppler.ecc;
+  params.orbit.period              = pulsarParams->Doppler.period;
   params.transfer                  = NULL;
   params.ephemerides               = edat;
   params.fHeterodyne               = fHet;
@@ -486,9 +489,7 @@ XLALFindSmallestValidSamplingRate ( UINT4 *n1,				//< [out] minimal valid sampli
       // now reduce gap to remainder wrt Tsft
       INT4 gap_i = gap_i0 % Tsft;
 
-      XLALPrintInfo ("gap_i = %d s, remainder wrt Tsft=%d s = %d s: ", gap_i0, Tsft, gap_i );
       if ( (gap_i * nCur) % Tsft == 0 ) {
-        XLALPrintInfo ("Fits exactly with fSamp = %d / Tsft = %g\n", nCur, nCur / TsftREAL );
         continue;
       }
 
@@ -513,7 +514,7 @@ XLALFindSmallestValidSamplingRate ( UINT4 *n1,				//< [out] minimal valid sampli
       UINT4 nNew = (UINT4) ceil ( nCur / Tg ) * Tg;
 
       XLAL_CHECK ( nNew > nCur, XLAL_ETOL, "This seems wrong: nNew = %d !> nCur = %d, but should be greater!\n", nNew, nCur );
-      XLALPrintInfo ("Need to increase to fSamp = %d / Tsft = %g\n", nNew, nNew / TsftREAL );
+      XLALPrintInfo ("Need to increase from fSamp = %d/Tsft = %g to fSamp = %d / Tsft = %g\n", nCur, nCur/TsftREAL, nNew, nNew / TsftREAL );
 
       nCur = nNew;
 
@@ -553,7 +554,7 @@ gcd (UINT4 numer, UINT4 denom)
 } // gcd
 
 /**
- * Create PulsarParamsVector for numPulsars
+ * Create *zero-initialized* PulsarParamsVector for numPulsars
  */
 PulsarParamsVector *
 XLALCreatePulsarParamsVector ( UINT4 numPulsars )
@@ -585,8 +586,6 @@ XLALDestroyPulsarParamsVector ( PulsarParamsVector *ppvect )
     {
       for ( UINT4 i = 0 ; i < numPulsars; i ++ )
         {
-          BinaryOrbitParams *orbit = ppvect->data[i].Doppler.orbit;
-          XLALFree ( orbit );
           XLALFree ( ppvect->data[i].name );
         } // for i < numPulsars
       XLALFree ( ppvect->data );
@@ -607,7 +606,6 @@ XLALDestroyPulsarParams ( PulsarParams *params )
     return;
   }
   XLALFree ( params->name );
-  XLALFree ( params->Doppler.orbit );
   XLALFree ( params );
 
   return;
@@ -647,10 +645,9 @@ XLALReadPulsarParams ( PulsarParams *pulsarParams,	///< [out] pulsar parameters
                        )
 {
   XLAL_CHECK ( pulsarParams != NULL, XLAL_EINVAL );
-  XLAL_CHECK ( pulsarParams->Doppler.orbit == NULL, XLAL_EINVAL );
   XLAL_CHECK ( cfgdata != NULL, XLAL_EINVAL );
 
-  INIT_MEM ( (*pulsarParams) );	// wipe input struct clean
+  XLAL_INIT_MEM ( (*pulsarParams) );	// wipe input struct clean
 
   // ---------- PulsarAmplitudeParams ----------
   // ----- h0, cosi
@@ -761,7 +758,7 @@ XLALReadPulsarParams ( PulsarParams *pulsarParams,	///< [out] pulsar parameters
   XLAL_CHECK ( XLALReadConfigREAL8Variable ( &orbitTpSSB, cfgdata, secName, "orbitTpSSB", &have_orbitTpSSB ) == XLAL_SUCCESS, XLAL_EFUNC );
   REAL8 orbitArgp = 0; 	BOOLEAN have_orbitArgp;
   XLAL_CHECK ( XLALReadConfigREAL8Variable ( &orbitArgp, cfgdata, secName, "orbitArgp", &have_orbitArgp ) == XLAL_SUCCESS, XLAL_EFUNC );
-  REAL8 orbitasini = 0; BOOLEAN have_orbitasini;
+  REAL8 orbitasini = 0 /* isolated pulsar */; BOOLEAN have_orbitasini;
   XLAL_CHECK ( XLALReadConfigREAL8Variable ( &orbitasini, cfgdata, secName, "orbitasini", &have_orbitasini ) == XLAL_SUCCESS, XLAL_EFUNC );
   REAL8 orbitEcc = 0;  	BOOLEAN have_orbitEcc;
   XLAL_CHECK ( XLALReadConfigREAL8Variable ( &orbitEcc, cfgdata, secName, "orbitEcc", &have_orbitEcc ) == XLAL_SUCCESS, XLAL_EFUNC );
@@ -774,17 +771,13 @@ XLALReadPulsarParams ( PulsarParams *pulsarParams,	///< [out] pulsar parameters
       XLAL_CHECK ( (orbitasini == 0) || ( have_orbitEcc && have_orbitPeriod && have_orbitArgp && have_orbitTpSSB ), XLAL_EINVAL );
       XLAL_CHECK ( (orbitEcc >= 0) && (orbitEcc <= 1), XLAL_EDOM );
 
-      BinaryOrbitParams *orbit;
-      XLAL_CHECK ( ( orbit = XLALCalloc ( 1, sizeof(BinaryOrbitParams))) != NULL, XLAL_ENOMEM );
-
       /* fill in orbital parameter structure */
-      XLAL_CHECK ( XLALGPSSetREAL8 ( &(orbit->tp), orbitTpSSB ) != NULL, XLAL_EFUNC );
-      orbit->argp 	= orbitArgp;
-      orbit->asini 	= orbitasini;
-      orbit->ecc 	= orbitEcc;
-      orbit->period 	= orbitPeriod;
+      XLAL_CHECK ( XLALGPSSetREAL8 ( &(pulsarParams->Doppler.tp), orbitTpSSB ) != NULL, XLAL_EFUNC );
+      pulsarParams->Doppler.argp 	= orbitArgp;
+      pulsarParams->Doppler.asini 	= orbitasini;
+      pulsarParams->Doppler.ecc 	= orbitEcc;
+      pulsarParams->Doppler.period 	= orbitPeriod;
 
-      pulsarParams->Doppler.orbit = orbit;
     } // if have non-trivial orbit
 
   // ---------- transientWindow_t ----------
@@ -873,62 +866,102 @@ XLALPulsarParamsFromFile ( const char *fname 		///< [in] 'CWsources' config file
 /**
  * Function to determine the PulsarParamsVector input from a user-input defining CW sources.
  *
- * This option supports a dual-type feature: if the input starts with a '@', then
- * it determines a list of input config-files to be parsed by XLALFindFiles(),
- * otherwise the input will be interpreted as a config-file string directly (with
- * options separated by ';' and/or newlines)
+ * This option supports a dual-type feature: if the any string in the list is of the form '{...}', then
+ * it determines the *contents* of a config-file, otherwise the name-pattern of config-files to be parsed by XLALFindFiles(),
+ * NOTE: when specifying file-contents, options can be separated by ';' and/or newlines)
  */
 PulsarParamsVector *
-XLALPulsarParamsFromUserInput ( const char *UserInput		///< [in] user-input string defining 'CW sources'
+XLALPulsarParamsFromUserInput ( const LALStringVector *UserInput		///< [in] user-input CSV list defining 'CW sources'
                                 )
 {
   XLAL_CHECK_NULL ( UserInput, XLAL_EINVAL );
+  XLAL_CHECK_NULL ( UserInput->length > 0, XLAL_EINVAL );
 
-  PulsarParamsVector *sources = NULL;
+  PulsarParamsVector *allSources = NULL;
 
-  if ( UserInput[0] == '@' )
+  for ( UINT4 l = 0; l < UserInput->length; l ++ )
     {
-      LALStringVector *file_list;
-      XLAL_CHECK_NULL ( ( file_list = XLALFindFiles ( &UserInput[1] )) != NULL, XLAL_EFUNC );
-      UINT4 numFiles = file_list->length;
-      for ( UINT4 i = 0; i < numFiles; i ++ )
+      const char *thisInput = UserInput->data[l];
+
+      if ( thisInput[0] != '{' )	// if it's an actual file-specification
         {
-          PulsarParamsVector *sources_i;
-          XLAL_CHECK_NULL ( (sources_i = XLALPulsarParamsFromFile ( file_list->data[i] )) != NULL, XLAL_EFUNC );
-
-          if ( sources == NULL )
+          LALStringVector *file_list;
+          XLAL_CHECK_NULL ( ( file_list = XLALFindFiles ( &thisInput[0] )) != NULL, XLAL_EFUNC );
+          UINT4 numFiles = file_list->length;
+          for ( UINT4 i = 0; i < numFiles; i ++ )
             {
-              sources = sources_i;
-            }
-          else
-            {
-              UINT4 oldlen = sources->length;
-              UINT4 addlen = sources_i->length;
-              UINT4 newlen = oldlen + addlen;
-              sources->length = newlen;
-              XLAL_CHECK_NULL ( (sources->data = XLALRealloc ( sources->data, newlen * sizeof(sources->data[0]) )) != NULL, XLAL_ENOMEM );
-              memcpy ( sources->data + oldlen, sources_i->data, addlen * sizeof(sources->data[0]) );
-              XLALFree ( sources_i->data );
-              XLALFree ( sources_i );
-            }
-        } // for i < numFiles
+              PulsarParamsVector *sources_i;
+              XLAL_CHECK_NULL ( (sources_i = XLALPulsarParamsFromFile ( file_list->data[i] )) != NULL, XLAL_EFUNC );
 
-      XLALDestroyStringVector ( file_list );
+              XLAL_CHECK_NULL ( (allSources = XLALPulsarParamsVectorAppend ( allSources, sources_i )) != NULL, XLAL_EFUNC );
+              XLALDestroyPulsarParamsVector ( sources_i );
+            } // for i < numFiles
 
-    } // if file-name spec given
-  else
-    {
-      LALParsedDataFile *cfgdata = NULL;
-      XLAL_CHECK_NULL ( XLALParseDataFileContent ( &cfgdata, UserInput ) == XLAL_SUCCESS, XLAL_EFUNC );
+          XLALDestroyStringVector ( file_list );
 
-      XLAL_CHECK_NULL ( (sources = XLALCreatePulsarParamsVector ( 1 )) != NULL, XLAL_EFUNC );
+        } // if file-pattern given
+      else
+        {
+          UINT4 len = strlen(thisInput);
+          XLAL_CHECK_NULL ( (thisInput[0] == '{') && (thisInput[len-1] == '}'), XLAL_EINVAL, "Invalid file-content input:\n%s\n", thisInput );
+          char *buf;
+          XLAL_CHECK_NULL ( (buf = XLALStringDuplicate ( &thisInput[1] )) != NULL, XLAL_EFUNC );
+          len = strlen(buf);
+          buf[len-1] = 0;	// remove trailing '}'
 
-      XLAL_CHECK_NULL ( XLALReadPulsarParams ( &sources->data[0], cfgdata, NULL ) == XLAL_SUCCESS, XLAL_EFUNC );
-      XLAL_CHECK_NULL ( (sources->data[0].name = XLALStringDuplicate ( "from-commandline" )) != NULL, XLAL_EFUNC );
-      XLALDestroyParsedDataFile ( cfgdata );
+          LALParsedDataFile *cfgdata = NULL;
+          XLAL_CHECK_NULL ( XLALParseDataFileContent ( &cfgdata, buf ) == XLAL_SUCCESS, XLAL_EFUNC );
+          XLALFree ( buf );
 
-    } // if direct config-string given
+          PulsarParamsVector *addSource;
+          XLAL_CHECK_NULL ( (addSource = XLALCreatePulsarParamsVector ( 1 )) != NULL, XLAL_EFUNC );
 
-  return sources;
+          XLAL_CHECK_NULL ( XLALReadPulsarParams ( &addSource->data[0], cfgdata, NULL ) == XLAL_SUCCESS, XLAL_EFUNC );
+          XLAL_CHECK_NULL ( (addSource->data[0].name = XLALStringDuplicate ( "direct-string-input" )) != NULL, XLAL_EFUNC );
+          XLALDestroyParsedDataFile ( cfgdata );
+
+          XLAL_CHECK_NULL ( (allSources = XLALPulsarParamsVectorAppend ( allSources, addSource )) != NULL, XLAL_EFUNC );
+          XLALDestroyPulsarParamsVector ( addSource );
+
+        } // if direct config-string given
+
+    } // for l < len(UserInput)
+
+  return allSources;
 
 } // XLALPulsarParamsFromUserInput()
+
+/**
+ * Append the given PulsarParamsVector 'add' to the vector 'list' ( which can be NULL), return resulting list
+ * with new elements 'add' appended at the end of 'list'.
+ */
+PulsarParamsVector *
+XLALPulsarParamsVectorAppend ( PulsarParamsVector *list, const PulsarParamsVector *add )
+{
+  XLAL_CHECK_NULL ( add != NULL, XLAL_EINVAL );
+
+  PulsarParamsVector *ret;
+  if ( list == NULL )
+    {
+      XLAL_CHECK_NULL ( (ret = XLALCalloc ( 1, sizeof(*ret))) != NULL, XLAL_ENOMEM );
+    }
+  else
+    {
+      ret = list;
+    }
+
+  UINT4 oldlen = ret->length;
+  UINT4 addlen = add->length;
+  UINT4 newlen = oldlen + addlen;
+  ret->length = newlen;
+  XLAL_CHECK_NULL ( (ret->data = XLALRealloc ( ret->data, newlen * sizeof(ret->data[0]) )) != NULL, XLAL_ENOMEM );
+  memcpy ( ret->data + oldlen, add->data, addlen * sizeof(ret->data[0]) );
+  // we have to properly copy the 'name' string fields
+  for ( UINT4 i = 0; i < addlen; i ++ )
+    {
+      XLAL_CHECK_NULL ( (ret->data[oldlen + i].name = XLALStringDuplicate ( add->data[i].name )) != NULL, XLAL_EFUNC );
+    }
+
+  return ret;
+
+} // XLALPulsarParamsVectorAppend()
