@@ -53,7 +53,7 @@
 
 /*---------- INCLUDES ----------*/
 #include <lal/LALComputeAM.h>
-#include <lal/ComputeFstat.h>
+#include <lal/CWFastMath.h>
 
 /*---------- local DEFINES and macros ----------*/
 
@@ -61,15 +61,6 @@
 
 /*---------- internal types ----------*/
 
-/*---------- Global variables ----------*/
-/* empty initializers  */
-const AMCoeffs empty_AMCoeffs;
-const MultiAMCoeffs empty_MultiAMCoeffs;
-const AntennaPatternMatrix empty_AntennaPatternMatrix;
-
-static const LALStatus empty_LALStatus;
-static const EarthState empty_EarthState;
-
 /*---------- internal prototypes ----------*/
 
 
@@ -152,8 +143,12 @@ LALGetAMCoeffs(LALStatus *status,				/**< [in/out] LAL status structure pointer
     REAL4 sin1lambda, cos1lambda;
     REAL4 sin2lambda, cos2lambda;
 
-    sin_cos_LUT (&sin2gamma, &cos2gamma, 2.0f * gam );
-    sin_cos_LUT (&sin1lambda, &cos1lambda, lambda );
+    if( XLALSinCosLUT (&sin2gamma, &cos2gamma, 2.0f * gam ) != XLAL_SUCCESS )
+      ABORT( status->statusPtr, LAL_EXLAL, "XLALSinCosLUT (&sin2gamma, &cos2gamma, 2.0f * gam ) failed" );
+
+    if( XLALSinCosLUT (&sin1lambda, &cos1lambda, lambda ) != XLAL_SUCCESS )
+      ABORT( status->statusPtr, LAL_EXLAL, "XLALSinCosLUT (&sin1lambda, &cos1lambda, lambda ) failed" );
+
 
     sin2lambda = 2.0f * sin1lambda * cos1lambda;
     cos2lambda = cos1lambda * cos1lambda - sin1lambda * sin1lambda;
@@ -176,7 +171,9 @@ LALGetAMCoeffs(LALStatus *status,				/**< [in/out] LAL status structure pointer
   alpha = skypos.longitude;
   delta = skypos.latitude;
 
-  sin_cos_LUT (&sin1delta, &cos1delta, delta );
+  if( XLALSinCosLUT (&sin1delta, &cos1delta, delta ) != XLAL_SUCCESS )
+    ABORT( status->statusPtr, LAL_EXLAL, "XLALSinCosLUT (&sin1delta, &cos1delta, delta ) failed" );
+
   sin2delta = 2.0f * sin1delta * cos1delta;
   cos2delta = cos1delta * cos1delta - sin1delta * sin1delta;
 
@@ -207,7 +204,9 @@ LALGetAMCoeffs(LALStatus *status,				/**< [in/out] LAL status structure pointer
 
       ah = alpha - DetectorStates->data[i].LMST;
 
-      sin_cos_LUT ( &sin1ah, &cos1ah, ah );
+      if( XLALSinCosLUT ( &sin1ah, &cos1ah, ah ) != XLAL_SUCCESS )
+        ABORT( status->statusPtr, LAL_EXLAL, "XLALSinCosLUT ( &sin1ah, &cos1ah, ah ) failed" );
+
       sin2ah = 2.0f * sin1ah * cos1ah;
       cos2ah = cos1ah * cos1ah - sin1ah * sin1ah;
 
@@ -292,8 +291,12 @@ LALNewGetAMCoeffs(LALStatus *status,			/**< [in/out] LAL status structure pointe
   alpha = skypos.longitude;
   delta = skypos.latitude;
 
-  sin_cos_LUT (&sin1delta, &cos1delta, delta );
-  sin_cos_LUT (&sin1alpha, &cos1alpha, alpha );
+  if( XLALSinCosLUT (&sin1delta, &cos1delta, delta ) != XLAL_SUCCESS )
+    ABORT( status->statusPtr, LAL_EXLAL, "XLALSinCosLUT (&sin1delta, &cos1delta, delta ) failed" );
+
+  if( XLALSinCosLUT (&sin1alpha, &cos1alpha, alpha ) != XLAL_SUCCESS )
+    ABORT( status->statusPtr, LAL_EXLAL, "XLALSinCosLUT (&sin1alpha, &cos1alpha, alpha ) failed" );
+
   // see Eq.(17) in CFSv2 notes (version v3):
   // https://dcc.ligo.org/cgi-bin/private/DocDB/ShowDocument?docid=1665&version=3
   xi1 =   sin1alpha;
@@ -373,8 +376,8 @@ XLALComputeAntennaPatternCoeffs ( REAL8 *ai,   			/**< [out] antenna-pattern fun
 				  const EphemerisData *edat	/**< [in] ephemeris-data */
 				  )
 {
-  LALStatus status = empty_LALStatus;
-  EarthState earth = empty_EarthState;
+  LALStatus XLAL_INIT_DECL(status);
+  EarthState XLAL_INIT_DECL(earth);
 
   if ( !ai || !bi || !skypos || !tGPS || !site || !edat) {
     XLAL_ERROR( XLAL_EINVAL );
@@ -662,7 +665,7 @@ XLALWeightMultiAMCoeffs (  MultiAMCoeffs *multiAMcoef, const MultiNoiseWeights *
       }
     } // for X < numDetectors
 
-  REAL8 Ad = 0, Bd = 0, Cd = 0;	// multi-IFO values
+  REAL4 Ad = 0, Bd = 0, Cd = 0;	// multi-IFO values
   /* ---------- main loop over detectors X ---------- */
   for ( X=0; X < numDetectors; X ++)
     {
@@ -684,12 +687,12 @@ XLALWeightMultiAMCoeffs (  MultiAMCoeffs *multiAMcoef, const MultiNoiseWeights *
         } // if weights
 
       UINT4 alpha;	// SFT-index
-      REAL8 AdX = 0, BdX = 0, CdX = 0;	// single-IFO values
+      REAL4 AdX = 0, BdX = 0, CdX = 0;	// single-IFO values
       /* compute single-IFO antenna-pattern coefficients AX,BX,CX, by summing over time-steps 'alpha' */
       for(alpha = 0; alpha < numStepsX; alpha++)
         {
-          REAL8 ahat = amcoeX->a->data[alpha];
-          REAL8 bhat = amcoeX->b->data[alpha];
+          REAL4 ahat = amcoeX->a->data[alpha];
+          REAL4 bhat = amcoeX->b->data[alpha];
 
           AdX += ahat * ahat;
           BdX += bhat * bhat;
@@ -767,8 +770,8 @@ XLALComputeAMCoeffs ( const DetectorStateSeries *DetectorStates,	/**< timeseries
 
   REAL4 sin1delta, cos1delta;
   REAL4 sin1alpha, cos1alpha;
-  sin_cos_LUT (&sin1delta, &cos1delta, delta );
-  sin_cos_LUT (&sin1alpha, &cos1alpha, alpha );
+  XLAL_CHECK_NULL( XLALSinCosLUT (&sin1delta, &cos1delta, delta ) == XLAL_SUCCESS, XLAL_EFUNC );
+  XLAL_CHECK_NULL( XLALSinCosLUT (&sin1alpha, &cos1alpha, alpha ) == XLAL_SUCCESS, XLAL_EFUNC );
 
   REAL4 xi1 = - sin1alpha;
   REAL4 xi2 =  cos1alpha;
