@@ -96,7 +96,7 @@ extern "C" {
  * combined by logical \c AND.
  *
  * <b>Note 2:</b> if a timestamps-list is given, *ALL* timestamps within
- * <tt>[startTime, endTime]</tt> MUST be found!]
+ * <tt>[minStartTime, maxStartTime)</tt> MUST be found!]
  *
  * <b>Note 3:</b> LALSFTdataFind() will refuse to return any SFTs without their detector-name
  * properly set. This applies only to v1-SFTs, for which you have to use constraints->detector,
@@ -164,51 +164,6 @@ extern "C" {
 
 /*@{*/
 
-/** \name Error codes */
-/*@{*/
-#define SFTFILEIO_ENULL 	1
-#define SFTFILEIO_EFILE 	2
-#define SFTFILEIO_EHEADER 	3
-#define SFTFILEIO_EVERSION 	4
-#define SFTFILEIO_EVAL 		5
-
-#define SFTFILEIO_EDIFFTSFT	6
-#define SFTFILEIO_EDIFFDET	7
-#define SFTFILEIO_EDETECTOR	8
-
-#define SFTFILEIO_ENONULL 	12
-#define SFTFILEIO_EFREQBAND 	13
-#define SFTFILEIO_EMEM 		14
-#define SFTFILEIO_EGLOB 	15
-#define SFTFILEIO_EDIFFLENGTH 	17
-#define SFTFILEIO_ESFTFORMAT	18
-#define SFTFILEIO_ESFTWRITE	19
-#define SFTFILEIO_ECONSTRAINTS  20
-#define SFTFILEIO_EMERGEDSFT  	21
-#define SFTFILEIO_ECRC64  	22
-
-#define SFTFILEIO_MSGENULL 	"Null pointer"
-#define SFTFILEIO_MSGEFILE 	"Error in file-IO"
-#define SFTFILEIO_MSGEHEADER 	"Incorrect header in file"
-#define SFTFILEIO_MSGEVERSION 	"This SFT-version is not currently supported"
-#define SFTFILEIO_MSGEVAL  	"Invalid value"
-
-#define SFTFILEIO_MSGEDIFFTSFT	"Inconsistent values of Tsft for matched SFTs"
-#define SFTFILEIO_MSGEDIFFDET	"Inconsistent detector-values for matched SFTs"
-#define SFTFILEIO_MSGEDETECTOR	"Illegal detector name"
-
-#define SFTFILEIO_MSGENONULL  	"Output pointer not NULL"
-#define SFTFILEIO_MSGEFREQBAND 	"Required frequency-band is not in SFT"
-#define SFTFILEIO_MSGEMEM 	"Out of memory"
-#define SFTFILEIO_MSGEGLOB 	"Failed to get filelist from directory/pattern"
-#define SFTFILEIO_MSGEDIFFLENGTH "Sorry, can only read SFTs of identical length (currently)"
-#define SFTFILEIO_MSGESFTFORMAT	 "Illegal SFT-format"
-#define SFTFILEIO_MSGESFTWRITE	 "Failed to write SFT to file"
-#define SFTFILEIO_MSGECONSTRAINTS "Could not satisfy the requested SFT-query constraints"
-#define SFTFILEIO_MSGEMERGEDSFT   "Inconsistent blocks in merged SFT"
-#define SFTFILEIO_MSGECRC64	"Invalid CRC64 checksum in SFT"
-/*@}*/
-
 // ---------- exported types ----------
 
 /** A vector of COMPLEX8FrequencySeries */
@@ -281,13 +236,13 @@ typedef struct tagMultiSFTVector {
  * 'Constraints' for SFT-matching: which detector, within which time-stretch and which
  * timestamps exactly should be loaded ?
  * Any of the entries is optional, and they will be combined by logical AND.
- * Note however, that *ALL* timestamps within [startTime, endTime] MUST be found if specified.
+ * Note however, that *ALL* timestamps within [minStartTime, maxStartTime) MUST be found if specified.
  */
 typedef struct tagSFTConstraints
 {
   CHAR *detector;			/**< 2-char channel-prefix describing the detector (eg 'H1', 'H2', 'L1', 'G1' etc) */
-  LIGOTimeGPS *startTime;		/**< only include SFTs starting >= startTime */
-  LIGOTimeGPS *endTime;			/**< only include SFTs starting <= endTime */
+  LIGOTimeGPS *minStartTime;		/**< only include SFTs whose epoch is >= minStartTime */
+  LIGOTimeGPS *maxStartTime;		/**< only include SFTs whose epoch is <  maxStartTime */
   LIGOTimeGPSVector *timestamps;	/**< list of timestamps  */
 } SFTConstraints;
 
@@ -310,6 +265,9 @@ typedef struct tagSFTDescriptor
 /** An "SFT-catalogue": a vector of SFTdescriptors, as returned by LALSFTdataFind() */
 typedef struct tagSFTCatalog
 {
+#ifdef SWIG /* SWIG interface directives */
+  SWIGLAL(ARRAY_1D(SFTCatalog, SFTDescriptor, data, UINT4, length));
+#endif /* SWIG */
   UINT4 length;			/**< number of SFTs in catalog */
   SFTDescriptor *data;		/**< array of data-entries describing matched SFTs */
 } SFTCatalog;
@@ -325,29 +283,24 @@ typedef struct tagSFTCatalog
  */
 typedef struct tagMultiSFTCatalogView
 {
+#ifdef SWIG /* SWIG interface directives */
+  SWIGLAL(ARRAY_1D(MultiSFTCatalogView, SFTCatalog, data, UINT4, length));
+#endif /* SWIG */
   UINT4 length;			/**< number of detectors */
   SFTCatalog *data;		/**< array of SFT-catalog pointers */
 } MultiSFTCatalogView;
 
 
 /*---------- Global variables ----------*/
-/* empty init-structs for the types defined in here */
-extern const SFTConstraints empty_SFTConstraints;
-extern const SFTCatalog empty_SFTCatalog;
-extern const SFTtype empty_SFTtype;
-extern const SFTVector empty_SFTVector;
-extern const MultiSFTVector empty_MultiSFTVector;
-extern const MultiREAL4TimeSeries empty_MultiREAL4TimeSeries;
-extern const LIGOTimeGPSVector empty_LIGOTimeGPSVector;
-extern const MultiLIGOTimeGPSVector empty_MultiLIGOTimeGPSVector;
 
 /*
  * Functions Declarations (i.e., prototypes).
  */
 
-/*================================================================================
- * NEW API: allowing for SFT-v2
- *================================================================================*/
+int XLALCWGPSinRange( const LIGOTimeGPS gps, const LIGOTimeGPS* minGPS, const LIGOTimeGPS* maxGPS );
+
+LALStringVector *XLALFindFiles (const CHAR *globstring);
+
 SFTCatalog *XLALSFTdataFind ( const CHAR *file_pattern, const SFTConstraints *constraints );
 
 int XLALWriteSFTVector2Dir  ( const SFTVector *sftVect, const CHAR *dirname, const CHAR *SFTcomment, const CHAR *Misc );
@@ -376,66 +329,12 @@ char *XLALGetOfficialName4MergedSFTs ( const SFTVector *sfts, const char *Misc )
 char *XLALOfficialSFTFilename ( char site, char channel, UINT4 numSFTs, UINT4 Tsft, UINT4 GPS_start, UINT4 Tspan, const char *Misc );
 int XLALCheckValidDescriptionField ( const char *desc );
 
-/*================================================================================
- * DEPRECATED LAL-API [use XLAL-API whenever available]
- *================================================================================*/
-void LALReadTimestampsFile (LALStatus* , LIGOTimeGPSVector **timestamps, const CHAR *fname); /* use XLALReadTimestampsFile() instead! */
-void LALSFTdataFind (LALStatus *, SFTCatalog **catalog, const CHAR *file_pattern, SFTConstraints *constraints);
-void LALLoadSFTs ( LALStatus *, SFTVector **sfts, const SFTCatalog *catalog, REAL8 fMin, REAL8 fMax);
-void LALLoadMultiSFTs ( LALStatus *status, MultiSFTVector **sfts, const SFTCatalog *catalog, REAL8 fMin, REAL8 fMax);
-void LALWriteSFT2file (LALStatus *, const SFTtype *sft, const CHAR *fname, const CHAR *SFTcomment );
-void LALWriteSFTVector2Dir (LALStatus *, const SFTVector *sftVect, const CHAR *basename, const CHAR *SFTcomment, const CHAR *description);
-
-void LALWrite_v2SFT_to_v1file (LALStatus *, const SFTtype *sft, const CHAR *fname);
-void LALCheckSFTs ( LALStatus *, INT4 *check_result, const CHAR *file_pattern, SFTConstraints *constraints );
-void LALCheckSFTCatalog ( LALStatus *status, INT4 *check_result, SFTCatalog *catalog );
-
-void LALDestroySFTCatalog ( LALStatus *status, SFTCatalog **catalog );
-void LALSFTtimestampsFromCatalog (LALStatus *, LIGOTimeGPSVector **timestamps, const SFTCatalog *catalog );
-
-LALStringVector *XLALFindFiles (const CHAR *globstring);
-
-/*================================================================================
- * OBSOLETE v1-only API [DEPRECATED!]
- *================================================================================*/
-
-/**
- * [DEPRECATED] This structure contains the header-info contained in an SFT-file of specification
- * version v1.0.
- */
-typedef struct tagSFTHeader {
-  REAL8  version;		/**< SFT version-number (currently only 1.0 allowed )*/
-  INT4   gpsSeconds;		/**< gps start-time (seconds)*/
-  INT4   gpsNanoSeconds;	/**< gps start-time (nanoseconds) */
-  REAL8  timeBase;		/**< length of data-stretch in seconds */
-  INT4   fminBinIndex;		/**< first frequency-index contained in SFT */
-  INT4   length;  		/**< number of frequency bins */
-} SFTHeader;
-
-
-
-void LALReadSFTheader (LALStatus *, SFTHeader *header, const CHAR *fname);
-void LALReadSFTdata (LALStatus *, SFTtype *sft, const CHAR *fname, INT4 fminBinIndex);
-void LALWriteSFTfile (LALStatus *, const SFTtype *sft, const CHAR *outfname);
-void LALReadSFTfile (LALStatus *, SFTtype **sft, REAL8 fMin, REAL8 fMax, const CHAR *fname);
-
-void LALReadSFTfiles (LALStatus *,
-		      SFTVector **sftvect,
-		      REAL8 fMin,
-		      REAL8 fMax,
-		      UINT4 wingBins,
-		      const CHAR *fpattern);
-
-void
-LALGetSFTheaders (LALStatus *,
-		  SFTVector **headers,
-		  const CHAR *fpattern,
-		  const LIGOTimeGPS *startTime,
-		  const LIGOTimeGPS *endTime);
-
-
 /*@}*/
 
+// ---------- obsolete LAL-API was moved into external file
+#include <lal/SFTfileIO-LAL.h>
+// ------------------------------
+
 #ifdef  __cplusplus
 }                /* Close C++ protection */
 #endif
