@@ -45,27 +45,8 @@
 
 /* ----- MACRO definitions ---------- */
 #define SQ(x) ((x)*(x))
-#define LAL_INT4_MAX 2147483647
 
 /* ---------- internal prototypes ---------- */
-/* empty struct initializers */
-const transientCandidate_t empty_transientCandidate;
-const transientWindow_t empty_transientWindow;
-const transientWindowRange_t empty_transientWindowRange;
-const transientFstatMap_t empty_transientFstatMap;
-
-/* ----- module-local fast lookup-table handling of negative exponentials ----- */
-
-/**
- * Lookup-table for negative exponentials e^(-x)
- * Holds an array 'data' of 'length' for values e^(-x) for x in the range [0, xmax]
- */
-#define EXPLUT_XMAX 	20.0	// LUT down to e^(-20) = 2.0612e-09
-#define EXPLUT_LENGTH 	2000	// number of LUT values to pre-compute
-static gsl_vector *expLUT = NULL; 	/**< module-global lookup-table for negative exponentials e^(-x) */
-#define EXPLUT_DXINV  ((EXPLUT_LENGTH)/(EXPLUT_XMAX))	// 1/dx with dx = xmax/length
-
-static int XLALCreateExpLUT ( void );	/* only ever used internally, destructor is in exported API */
 
 static const char *transientWindowNames[TRANSIENT_LAST] =
   {
@@ -142,7 +123,7 @@ XLALGetTransientWindowTimespan ( UINT4 *t0,				/**< [out] window start-time */
        * with the e-folding factor chosen such that the window-value
        * is practically negligible after that, where it will be set to 0
        */
-      (*t1) = (UINT4)( win_t0 + TRANSIENT_EXP_EFOLDING * win_tau + 0.5 );
+      (*t1) = lround( win_t0 + TRANSIENT_EXP_EFOLDING * win_tau);
       break;
     case TRANSIENT_RECTANGULAR:
       (*t0) = win_t0;
@@ -196,7 +177,7 @@ XLALApplyTransientWindow ( REAL4TimeSeries *series,		/**< input timeseries to ap
     case TRANSIENT_RECTANGULAR:
       for ( i = 0; i < ts_length; i ++ )
         {
-          UINT4 ti = (UINT4) ( ts_t0 + i * ts_dt + 0.5 );	// integer round: floor(x+0.5)
+          UINT4 ti = lround ( ts_t0 + i * ts_dt );
           if ( ti < t0 || ti > t1 ) { // outside rectangular window: set to zero
             series->data->data[i] = 0;
           } // otherwise do nothing
@@ -206,7 +187,7 @@ XLALApplyTransientWindow ( REAL4TimeSeries *series,		/**< input timeseries to ap
     case TRANSIENT_EXPONENTIAL:
       for ( i = 0; i < ts_length; i ++ )
         {
-          UINT4 ti = (UINT4) ( ts_t0 + i * ts_dt + 0.5 );
+          UINT4 ti = lround ( ts_t0 + i * ts_dt );
           REAL8 win = XLALGetExponentialTransientWindowValue ( ti, t0, t1, transientWindow.tau );
           series->data->data[i] *= win;
         } /* for i < length */
@@ -356,7 +337,7 @@ XLALPulsarDopplerParams2String ( const PulsarDopplerParams *par )
 	}
     }
 
-  if ( par->orbit )
+  if ( par->asini > 0 )
     {
       LogPrintf(LOG_NORMAL, "%s: orbital params not supported in Doppler-filenames yet\n", __func__ );
     }
@@ -731,7 +712,8 @@ XLALComputeTransientFstatMap ( const MultiFstatAtomVector *multiFstatAtoms, 	/**
       if ( i_t0 >= numAtoms ) i_t0 = numAtoms - 1;
 
       /* ----- INNER loop over timescale-parameter tau ---------- */
-      REAL8 Ad=0, Bd=0, Cd=0, Fa_re=0, Fa_im=0, Fb_re=0, Fb_im=0;
+      REAL4 Ad=0, Bd=0, Cd=0;
+      COMPLEX8 Fa=0, Fb=0;
       UINT4 i_t1_last = i_t0;
 
       for ( n = 0; n < N_tauRange; n ++ )
@@ -771,7 +753,7 @@ XLALComputeTransientFstatMap ( const MultiFstatAtomVector *multiFstatAtoms, 	/**
             case TRANSIENT_RECTANGULAR:
 #if 0
               /* 'vanilla' unoptimized method, for sanity checks with 'optimized' method */
-              Ad=0; Bd=0; Cd=0; Fa_re=0; Fa_im=0; Fb_re=0; Fb_im=0;
+              Ad=0; Bd=0; Cd=0; Fa=0; Fb=0;
               for ( UINT4 i = i_t0; i <= i_t1; i ++ )
 #else
               /* special optimiziation in the rectangular-window case: just add on to previous tau values
@@ -787,11 +769,8 @@ XLALComputeTransientFstatMap ( const MultiFstatAtomVector *multiFstatAtoms, 	/**
                   Bd += thisAtom_i->b2_alpha;
                   Cd += thisAtom_i->ab_alpha;
 
-                  Fa_re += crealf(thisAtom_i->Fa_alpha);
-                  Fa_im += cimagf(thisAtom_i->Fa_alpha);
-
-                  Fb_re += crealf(thisAtom_i->Fb_alpha);
-                  Fb_im += cimagf(thisAtom_i->Fb_alpha);
+                  Fa += thisAtom_i->Fa_alpha;
+                  Fb += thisAtom_i->Fb_alpha;
 
                 } /* for i = i_t1_last : i_t1 */
 
@@ -801,7 +780,7 @@ XLALComputeTransientFstatMap ( const MultiFstatAtomVector *multiFstatAtoms, 	/**
 
             case TRANSIENT_EXPONENTIAL:
               /* reset all values */
-              Ad=0; Bd=0; Cd=0; Fa_re=0; Fa_im=0; Fb_re=0; Fb_im=0;
+              Ad=0; Bd=0; Cd=0; Fa=0; Fb=0;
 
               for ( UINT4 i = i_t0; i <= i_t1; i ++ )
                 {
@@ -817,11 +796,8 @@ XLALComputeTransientFstatMap ( const MultiFstatAtomVector *multiFstatAtoms, 	/**
                   Bd += thisAtom_i->b2_alpha * win2_i;
                   Cd += thisAtom_i->ab_alpha * win2_i;
 
-                  Fa_re += crealf(thisAtom_i->Fa_alpha) * win_i;
-                  Fa_im += cimagf(thisAtom_i->Fa_alpha) * win_i;
-
-                  Fb_re += crealf(thisAtom_i->Fb_alpha) * win_i;
-                  Fb_im += cimagf(thisAtom_i->Fb_alpha) * win_i;
+                  Fa += thisAtom_i->Fa_alpha * win_i;
+                  Fb += thisAtom_i->Fb_alpha * win_i;
 
                 } /* for i in [i_t0, i_t1] */
               break;
@@ -836,10 +812,9 @@ XLALComputeTransientFstatMap ( const MultiFstatAtomVector *multiFstatAtoms, 	/**
 
 
           /* generic F-stat calculation from A,B,C, Fa, Fb */
-          REAL8 DdInv = 1.0 / ( Ad * Bd - Cd * Cd );
-          REAL8 F = DdInv * ( Bd * (SQ(Fa_re) + SQ(Fa_im) ) + Ad * ( SQ(Fb_re) + SQ(Fb_im) )
-                              - 2.0 * Cd *( Fa_re * Fb_re + Fa_im * Fb_im )
-                              );
+          REAL4 DdInv = 1.0 / ( Ad * Bd - Cd * Cd );
+          REAL4 twoF = XLALComputeFstatFromFaFb ( Fa, Fb, Ad, Bd, Cd, 0, DdInv );
+          REAL4 F = 0.5 * twoF;
 
           /* keep track of loudest F-stat value encountered over the m x n matrix */
           if ( F > ret->maxF )
@@ -1044,87 +1019,6 @@ write_MultiFstatAtoms_to_fp ( FILE *fp, const MultiFstatAtomVector *multiAtoms )
 } /* write_MultiFstatAtoms_to_fp() */
 
 
-/**
- * Generate an exponential lookup-table expLUT for e^(-x)
- * over the interval x in [0, xmax], using 'length' points.
- */
-int
-XLALCreateExpLUT ( void )
-{
-  /* create empty output LUT */
-  gsl_vector *ret;
-  if ( ( ret = gsl_vector_alloc ( EXPLUT_LENGTH + 1)) == NULL ) {
-    XLALPrintError ("%s: failed to gsl_vector_alloc (%s)\n", __func__, EXPLUT_LENGTH +1 );
-    XLAL_ERROR ( XLAL_ENOMEM );
-  }
-
-  /* fill output LUT */
-  REAL8 dx = EXPLUT_XMAX / EXPLUT_LENGTH;
-  UINT4 i;
-  for ( i=0; i <= EXPLUT_LENGTH; i ++ )
-    {
-      REAL8 xi = i * dx;
-
-      gsl_vector_set ( ret, i, exp( - xi ) );
-
-    } /* for i < length() */
-
-  /* 'return' this by setting the global vector */
-  expLUT = ret;
-
-  return XLAL_SUCCESS;
-
-} /* XLALCreateExpLUT() */
-
-/**
- * Destructor function for expLUT_t lookup table
- */
-void
-XLALDestroyExpLUT ( void )
-{
-  if ( !expLUT )
-    return;
-
-  gsl_vector_free ( expLUT );
-
-  expLUT = NULL;
-
-  return;
-
-} /* XLALDestroyExpLUT() */
-
-/**
- * Fast exponential function e^-x using lookup-table (LUT).
- * We need to compute exp(-x) for x >= 0, typically in a B-stat
- * integral of the form int e^-x dx: this means that small values e^(-x)
- * will not contribute much to the integral and are less important than
- * values close to 1. Therefore we pre-compute a LUT of e^(-x) for x in [0, xmax],
- * in Npoints points, and set e^(-x) = 0 for x < xmax.
- *
- * NOTE: if module-global expLUT=NULL, we create it here
- * NOTE: if argument is negative, we use math-lib exp(-x) instead of LUT
- */
-REAL8
-XLALFastNegExp ( REAL8 mx )
-{
-  if ( mx > EXPLUT_XMAX )	/* for values smaller than e^(-xmax) we truncate to 0 */
-    return 0.0;
-
-  if ( mx < 0 )
-    return exp ( - mx  );
-
-  /* if lookup table doesn't exist yet: generate it now */
-  if ( !expLUT && ( XLALCreateExpLUT() != XLAL_SUCCESS) ) {
-    XLAL_ERROR_REAL8 ( XLAL_EFUNC );
-  }
-
-  /* find index of closest point xp in LUT to xm */
-  UINT4 i0 = (UINT4) ( mx * EXPLUT_DXINV + 0.5 );
-
-  return gsl_vector_get ( expLUT, i0 );
-
-} /* XLALFastNegExp() */
-
 /**
  * Standard destructor for transientFstatMap_t
  * Fully NULL-robust as usual.
