@@ -118,9 +118,6 @@ do { 											\
 
 #define GPS2REAL8(gps) (1.0 * (gps).gpsSeconds + 1.e-9 * (gps).gpsNanoSeconds )
 
-/*---------- empty initializers ---------- */
-LALStatus empty_status;
-SFTConstraints empty_constraints;
 /*---------- Global variables ----------*/
 
 /* ----------------------------------------------------------------------*/
@@ -184,10 +181,10 @@ static int CompareSFTVectors(SFTVector *sft_vect, SFTVector *sft_vect2)
 int main(int argc, char *argv[])
 {
   const char *fn = __func__;
-  LALStatus status = empty_status;
+  LALStatus XLAL_INIT_DECL(status);
 
   SFTCatalog *catalog = NULL;
-  SFTConstraints constraints = empty_constraints;
+  SFTConstraints XLAL_INIT_DECL(constraints);
   SFTVector *sft_vect = NULL;
   SFTVector *sft_vect2 = NULL;
   MultiSFTVector *multsft_vect = NULL;
